@@ -5,4 +5,4 @@
 ##########################################################################
 
 java = 'java'
-supported_formats = ('pdf', 'rtf', 'wml', 'docx', 'odt')
+supported_formats = ('pdf', 'pdf2', 'rtf', 'wml', 'docx', 'odt')
