@@ -14,6 +14,7 @@ from html2fo import HTML2FOConverter
 from fo2xfc import (xfc_available, RTFConverter, ODTConverter, 
                     WMLConverter, DOCXConverter)
 from fo2pdf import xinc_available, PDFConverter
+from fo2fop import fop_available, FOPPDFConverter
 
 
 class Converter(object):
@@ -46,6 +47,11 @@ class Converter(object):
                 raise RuntimeError("The external XINC converter isn't available")
             output_filename = PDFConverter().convert(self.fo_filename, output_filename=output_filename)
 
+        elif format == 'pdf2':
+            if not fop_available:
+                raise RuntimeError("The external FOP converter isn't available")
+            output_filename = FOPPDFConverter().convert(self.fo_filename, output_filename=output_filename)
+
         else:
             if not xfc_available:
                 raise RuntimeError("The external XFC converter isn't available")
